@@ -1,6 +1,6 @@
 use cosmwasm_std::entry_point;
 use cosmwasm_std::{
-    to_binary, Addr, Binary, Deps, DepsMut, Env, MessageInfo, Order, Pair, Response, StdResult,
+    to_binary, Addr, Binary, Deps, DepsMut, Env, MessageInfo, Order, Record, Response, StdResult,
     SubMsg, Uint128,
 };
 use cw_storage_plus::Bound;
@@ -478,7 +478,7 @@ pub fn query(deps: Deps, env: Env, msg: Cw1155QueryMsg) -> StdResult<Binary> {
     }
 }
 
-fn parse_approval(item: StdResult<Pair<Expiration>>) -> StdResult<cw1155::Approval> {
+fn parse_approval(item: StdResult<Record<Expiration>>) -> StdResult<cw1155::Approval> {
     item.and_then(|(k, expires)| {
         let spender = String::from_utf8(k)?;
         Ok(cw1155::Approval { spender, expires })
@@ -542,7 +542,7 @@ fn query_all_tokens(
 #[cfg(test)]
 mod tests {
     use cosmwasm_std::testing::{mock_dependencies, mock_env, mock_info};
-    use cosmwasm_std::{attr, OverflowError, StdError};
+    use cosmwasm_std::{OverflowError, StdError};
 
     use super::*;
 
@@ -606,15 +606,11 @@ mod tests {
                 mint_msg,
             )
             .unwrap(),
-            Response {
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token1),
-                    attr("amount", 1u64),
-                    attr("to", &user1),
-                ],
-                ..Response::default()
-            }
+            Response::new()
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token1)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("to", &user1)
         );
 
         // query balance
@@ -672,16 +668,12 @@ mod tests {
                 transfer_msg,
             )
             .unwrap(),
-            Response {
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token1),
-                    attr("amount", 1u64),
-                    attr("from", &user1),
-                    attr("to", &user2),
-                ],
-                ..Response::default()
-            }
+            Response::new()
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token1)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user1)
+                .add_attribute("to", &user2)
         );
 
         // query balance
@@ -725,19 +717,15 @@ mod tests {
                 },
             )
             .unwrap(),
-            Response {
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token2),
-                    attr("amount", 1u64),
-                    attr("to", &user2),
-                    attr("action", "transfer"),
-                    attr("token_id", &token3),
-                    attr("amount", 1u64),
-                    attr("to", &user2),
-                ],
-                ..Response::default()
-            }
+            Response::new()
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token2)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("to", &user2)
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token3)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("to", &user2)
         );
 
         // invalid batch transfer, (user2 not approved yet)
@@ -782,26 +770,22 @@ mod tests {
                 batch_transfer_msg,
             )
             .unwrap(),
-            Response {
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token1),
-                    attr("amount", 1u64),
-                    attr("from", &user2),
-                    attr("to", &user1),
-                    attr("action", "transfer"),
-                    attr("token_id", &token2),
-                    attr("amount", 1u64),
-                    attr("from", &user2),
-                    attr("to", &user1),
-                    attr("action", "transfer"),
-                    attr("token_id", &token3),
-                    attr("amount", 1u64),
-                    attr("from", &user2),
-                    attr("to", &user1),
-                ],
-                ..Response::default()
-            },
+            Response::new()
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token1)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user2)
+                .add_attribute("to", &user1)
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token2)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user2)
+                .add_attribute("to", &user1)
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token3)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user2)
+                .add_attribute("to", &user1)
         );
 
         // batch query
@@ -873,15 +857,11 @@ mod tests {
                 }
             )
             .unwrap(),
-            Response {
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token1),
-                    attr("amount", 1u64),
-                    attr("from", &user1),
-                ],
-                ..Response::default()
-            }
+            Response::new()
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token1)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user1)
         );
 
         // burn them all
@@ -896,19 +876,15 @@ mod tests {
                 }
             )
             .unwrap(),
-            Response {
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token2),
-                    attr("amount", 1u64),
-                    attr("from", &user1),
-                    attr("action", "transfer"),
-                    attr("token_id", &token3),
-                    attr("amount", 1u64),
-                    attr("from", &user1),
-                ],
-                ..Response::default()
-            }
+            Response::new()
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token2)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user1)
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token3)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user1)
         );
     }
 
@@ -955,8 +931,8 @@ mod tests {
                 },
             )
             .unwrap(),
-            Response {
-                messages: vec![SubMsg::new(
+            Response::new()
+                .add_message(
                     Cw1155ReceiveMsg {
                         operator: minter.clone(),
                         from: None,
@@ -966,15 +942,11 @@ mod tests {
                     }
                     .into_cosmos_msg(receiver.clone())
                     .unwrap()
-                ),],
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token1),
-                    attr("amount", 1u64),
-                    attr("to", &receiver),
-                ],
-                ..Response::default()
-            }
+                )
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token1)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("to", &receiver)
         );
 
         // BatchSendFrom
@@ -991,8 +963,8 @@ mod tests {
                 },
             )
             .unwrap(),
-            Response {
-                messages: vec![SubMsg::new(
+            Response::new()
+                .add_message(
                     Cw1155BatchReceiveMsg {
                         operator: user1.clone(),
                         from: Some(user1.clone()),
@@ -1001,16 +973,12 @@ mod tests {
                     }
                     .into_cosmos_msg(receiver.clone())
                     .unwrap()
-                )],
-                attributes: vec![
-                    attr("action", "transfer"),
-                    attr("token_id", &token2),
-                    attr("amount", 1u64),
-                    attr("from", &user1),
-                    attr("to", &receiver),
-                ],
-                ..Response::default()
-            }
+                )
+                .add_attribute("action", "transfer")
+                .add_attribute("token_id", &token2)
+                .add_attribute("amount", 1u64.to_string())
+                .add_attribute("from", &user1)
+                .add_attribute("to", &receiver)
         );
     }
 
